@@ -171,7 +171,10 @@ class AuthorizeResponder(ferny.AskpassHandler):
 
         # FIXME: is this a host key prompt? This should be handled more elegantly,
         # see https://github.com/cockpit-project/cockpit/pull/19668
-        fp_match = re.search(r'\n(\w+) key fingerprint is ([^.]+)\.', prompt)
+        # Since openssh 10.2p1-1 the host key prompt changed:
+        # - now includes a colon after "key fingerprint is"
+        # - does not end on a dot but a newline (likely for easier copy-pasting
+        fp_match = re.search(r'\n(\w+) key fingerprint is:? ([^.\n]+)', prompt)
         # let ssh resolve aliases, don't use our original "destination"
         host_match = re.search(r"authenticity of host '([^ ]+) ", prompt)
         args = {}
